NexAgent

#### 提示

#### 记忆详情

内容:

# NexAgent

###

### 新建会话

选择角色卡
会话名称（可选）

### 设置

#### 供应商

#### 工具管理

#### MCP 服务器

#### 角色卡管理

#### 向量记忆

启用向量记忆
AI 将记住用户的重要信息

#### OpenAI 兼容 API

#### 语音识别

配置 OpenAI 兼容的语音转文字(Transcription) API
Base URL API Key 模型名称
测试语音识别

#### 关于 NexAgent

NexAgent
版本 -
AI 对话框架，支持多服务商、多模型切换、深度思考、工具调用、MCP 服务器、流式输出、多会话管理。
多服务商
多模型
工具调用
MCP 支持

#### 插件系统

#### 样式设置

主题模式
主题色
界面字体大小
助手头像
自定义头像请在角色卡设置中上传

#### 服务商详情

##### 模型列表

服务商ID 显示名称 API Key Base URL

#### MCP 服务器

服务器ID 显示名称 服务器类型
服务器URL 请求头 (JSON, 可选)

#### 角色卡

角色名称 角色头像
P
系统提示词 最大输出长度 (max_tokens) 温度 (temperature: 0-2) Top P (0-1)

#### 模型设置

模型类型
模型ID 显示名称
模型能力
工具
推理
视觉

#### OpenAPI配置

API模型ID * 内部模型 *
角色卡
启用系统提示词注入

###

###

消息内容

### 模型列表